## ----setup, include=FALSE-----------------------------------------------------
source("https://raw.githubusercontent.com/Flavjack/inti/master/pkgdown/favicon/docs.r")

## ---- echo=TRUE, eval = FALSE-------------------------------------------------
#  open https://chocolatey.org/packages
#  
#  Start-Process powershell -Verb runAs
#  
#  Set-ExecutionPolicy Bypass -Scope Process -Force; [System.Net.ServicePointManager]::SecurityProtocol = [System.Net.ServicePointManager]::SecurityProtocol -bor 3072; iex ((New-Object System.Net.WebClient).DownloadString('https://chocolatey.org/install.ps1'))
#  
#  choco install avastfreeantivirus
#  choco install googlechrome
#  choco install winrar
#  choco install zotero
#  choco install r
#  choco install rtools
#  choco install r.studio
#  choco install git
#  choco install google-backup-and-sync
#  choco install foxitreader
#  choco install sharex
#  choco install k-litecodecpackfull
#  choco install gom-player
#  choco install aimp
#  choco install teamviewer

